Package: nmfkc
Type: Package
Title: Non-Negative Matrix Factorization with Kernel Covariates
Version: 0.8.2
Date: 2026-06-09
Authors@R: 
    person("Kenichi", "Satoh",
           email = "kenichi-satoh@biwako.shiga-u.ac.jp",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-4436-9347"))
Maintainer: Kenichi Satoh <kenichi-satoh@biwako.shiga-u.ac.jp>
URL: https://github.com/ksatohds/nmfkc,
        https://ksatohds.github.io/nmfkc/
BugReports: https://github.com/ksatohds/nmfkc/issues
Description: Performs Non-negative Matrix Factorization (NMF)
    with Kernel Covariates. Given an observation matrix and kernel
    covariates, it optimizes both a basis matrix and a parameter matrix.
    Notably, if the kernel matrix is an identity matrix, the method
    simplifies to standard NMF. Also provides NMF with Random Effects
    (NMF-RE) via nmfre(), which estimates a mixed-effects model combining
    covariate-driven scores with unit-specific random effects together
    with wild bootstrap inference, and NMF-based Structural Equation
    Modeling (NMF-SEM) via nmf.sem(), which fits a two-block input-output
    model for blind source separation and path analysis.
    References: Satoh (2025) <doi:10.48550/arXiv.2403.05359>;
    Satoh (2025) <doi:10.48550/arXiv.2510.10375>;
    Satoh (2025) <doi:10.48550/arXiv.2512.18250>;
    Satoh (2026) <doi:10.48550/arXiv.2603.01468>;
    Satoh (2026) <doi:10.1007/s42081-025-00314-0>.
License: MIT + file LICENSE
Imports: stats, graphics, utils, grDevices
Encoding: UTF-8
Language: en-US
ByteCompile: true
VignetteBuilder: knitr
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), mclust,
        palmerpenguins, quanteda, vars, DiagrammeR, MASS, nlme, lavaan
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2026-06-14 11:41:16 UTC; ksato
Author: Kenichi Satoh [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4436-9347>)
Repository: CRAN
Date/Publication: 2026-06-14 13:50:02 UTC
Built: R 4.5.2; ; 2026-06-14 13:58:21 UTC; unix
