# Generated by roxygen2: do not edit by hand

S3method(coef,nmf)
S3method(coef,nmf.sem)
S3method(fitted,nmf)
S3method(fitted,nmf.sem)
S3method(fitted,nmfae)
S3method(plot,nmf.cluster.criteria)
S3method(plot,nmf.cluster.flow)
S3method(plot,nmf.rank)
S3method(plot,nmf.sem)
S3method(plot,nmfae)
S3method(plot,nmfae.cv)
S3method(plot,nmfae.ecv)
S3method(plot,nmfae.kernel.beta.cv)
S3method(plot,nmfae.signed)
S3method(plot,nmfkc)
S3method(plot,nmfkc.DOT)
S3method(plot,nmfkc.ard)
S3method(plot,nmfkc.consensus)
S3method(plot,nmfkc.signed)
S3method(plot,nmfre)
S3method(plot,predict.nmfae)
S3method(predict,nmfae)
S3method(predict,nmfae.signed)
S3method(predict,nmfkc)
S3method(predict,nmfkc.signed)
S3method(print,nmf.cluster.criteria)
S3method(print,nmf.cluster.flow)
S3method(print,nmf.inference)
S3method(print,nmf.rank)
S3method(print,nmfkc.ard)
S3method(print,nmfkc.consensus)
S3method(print,nmfre.dfU.scan)
S3method(print,summary.nmf.sem)
S3method(print,summary.nmfae)
S3method(print,summary.nmfae.inference)
S3method(print,summary.nmfae.signed)
S3method(print,summary.nmfae.signed.inference)
S3method(print,summary.nmfkc)
S3method(print,summary.nmfkc.inference)
S3method(print,summary.nmfkc.net)
S3method(print,summary.nmfkc.net.inference)
S3method(print,summary.nmfkc.net.signed)
S3method(print,summary.nmfkc.signed)
S3method(residuals,nmf)
S3method(residuals,nmf.sem)
S3method(residuals,nmfae)
S3method(residuals,nmfre)
S3method(summary,nmf.sem)
S3method(summary,nmfae)
S3method(summary,nmfae.inference)
S3method(summary,nmfae.signed)
S3method(summary,nmfae.signed.inference)
S3method(summary,nmfkc)
S3method(summary,nmfkc.inference)
S3method(summary,nmfkc.net)
S3method(summary,nmfkc.net.inference)
S3method(summary,nmfkc.net.signed)
S3method(summary,nmfkc.signed)
S3method(summary,nmfre)
export(nmf.cluster.criteria)
export(nmf.cluster.flow)
export(nmf.ffb)
export(nmf.ffb.DOT)
export(nmf.ffb.cv)
export(nmf.ffb.inference)
export(nmf.ffb.split)
export(nmf.sem)
export(nmf.sem.DOT)
export(nmf.sem.cv)
export(nmf.sem.inference)
export(nmf.sem.split)
export(nmfae)
export(nmfae.DOT)
export(nmfae.cv)
export(nmfae.ecv)
export(nmfae.heatmap)
export(nmfae.inference)
export(nmfae.kernel.beta.cv)
export(nmfae.rank)
export(nmfae.rename)
export(nmfae.signed)
export(nmfae.signed.ecv)
export(nmfae.signed.heatmap)
export(nmfae.signed.inference)
export(nmfae.signed.rank)
export(nmfae.signed.rename)
export(nmfkc)
export(nmfkc.DOT)
export(nmfkc.ar)
export(nmfkc.ar.DOT)
export(nmfkc.ar.degree.cv)
export(nmfkc.ar.predict)
export(nmfkc.ar.stationarity)
export(nmfkc.ard)
export(nmfkc.bicv)
export(nmfkc.class)
export(nmfkc.consensus)
export(nmfkc.criterion)
export(nmfkc.cv)
export(nmfkc.denormalize)
export(nmfkc.ecv)
export(nmfkc.inference)
export(nmfkc.kernel)
export(nmfkc.kernel.beta.cv)
export(nmfkc.kernel.beta.nearest.med)
export(nmfkc.kernel.gaussian)
export(nmfkc.net)
export(nmfkc.net.DOT)
export(nmfkc.net.ecv)
export(nmfkc.net.inference)
export(nmfkc.net.rank)
export(nmfkc.normalize)
export(nmfkc.rank)
export(nmfkc.residual.plot)
export(nmfkc.signed)
export(nmfkc.signed.cv)
export(nmfkc.signed.ecv)
export(nmfkc.signed.rank)
export(nmfkc.signed.rff)
export(nmfre)
export(nmfre.dfU.scan)
export(nmfre.inference)
