% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nmfkc.net.R
\name{summary.nmfkc.net.inference}
\alias{summary.nmfkc.net.inference}
\title{Summary method for nmfkc.net.inference objects}
\usage{
\method{summary}{nmfkc.net.inference}(object, ...)
}
\arguments{
\item{object}{An object of class \code{"nmfkc.net.inference"}.}

\item{...}{Additional arguments passed to \code{summary.nmfkc}.}
}
\value{
An object of class \code{"summary.nmfkc.net.inference"}.
}
\description{
Produces a summary of a symmetric NMF model with inference results,
including the coefficients table for \eqn{C}.
}
\seealso{
\code{\link{nmfkc.net.inference}}
}
