% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nmfae.signed.R
\name{plot.nmfae.signed}
\alias{plot.nmfae.signed}
\title{Plot method for nmfae.signed (convergence)}
\usage{
\method{plot}{nmfae.signed}(x, ...)
}
\arguments{
\item{x}{An \code{nmfae.signed} object.}

\item{...}{Additional graphical parameters.}
}
\value{
Invisible \code{NULL}.
}
\description{
Displays the convergence trajectory of the objective function.
}
\section{Lifecycle}{

This function is \strong{experimental}. The interface may change in
future versions.
}

\references{
Ding, C. H. Q., Li, T., & Jordan, M. I. (2010). Convex and
semi-nonnegative matrix factorizations. \emph{IEEE Transactions on
Pattern Analysis and Machine Intelligence}, 32(1), 45--55.
}
\seealso{
\code{\link{nmfae.signed}}
}
