% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nmfkc.R
\name{nmfkc.denormalize}
\alias{nmfkc.denormalize}
\title{Denormalize a matrix from \eqn{[0,1]} back to its original scale}
\usage{
nmfkc.denormalize(x, ref = x)
}
\arguments{
\item{x}{A numeric matrix (or vector) with values in \eqn{[0,1]} to be denormalized.}

\item{ref}{A reference matrix used to obtain the original column-wise minima
and maxima. Must have the same number of columns as \code{x}.}
}
\value{
A numeric matrix with values transformed back to the original scale.
}
\description{
\code{nmfkc.denormalize} rescales a matrix with values in \eqn{[0,1]} back to its
original scale using the column-wise minima and maxima of a reference matrix.
}
\examples{
x <- nmfkc.normalize(iris[, -5])
x_recovered <- nmfkc.denormalize(x, iris[, -5])
apply(x_recovered - iris[, -5], 2, max)
}
\seealso{
\code{\link{nmfkc.normalize}}
}
