% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nmfkc.signed.R
\name{plot.nmfkc.signed}
\alias{plot.nmfkc.signed}
\title{Plot method for nmfkc.signed (convergence)}
\usage{
\method{plot}{nmfkc.signed}(x, ...)
}
\arguments{
\item{x}{An \code{nmfkc.signed} object.}

\item{...}{Passed to \code{plot()}.}
}
\value{
Invisible \code{x}.
}
\description{
Plot method for nmfkc.signed (convergence)
}
\section{Lifecycle}{

This function is \strong{experimental}. The interface may change in
future versions.
}

\references{
Ding, C. H. Q., Li, T., & Jordan, M. I. (2010). Convex and
semi-nonnegative matrix factorizations. \emph{IEEE Transactions on
Pattern Analysis and Machine Intelligence}, 32(1), 45--55.
}
