% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nmfkc.R
\name{print.summary.nmfkc}
\alias{print.summary.nmfkc}
\title{Print method for \code{summary.nmfkc} objects}
\usage{
\method{print}{summary.nmfkc}(x, digits = max(3L, getOption("digits") - 3L), ...)
}
\arguments{
\item{x}{An object of class \code{summary.nmfkc}.}

\item{digits}{Minimum number of significant digits to be used.}

\item{...}{Additional arguments (currently unused).}
}
\value{
Called for its side effect (printing). Returns \code{x} invisibly.
}
\description{
Prints a formatted summary of an \code{nmfkc} model fit.
}
\examples{
Y <- matrix(cars$dist, nrow = 1)
A <- rbind(1, cars$speed)
result <- nmfkc(Y, A, rank = 1)
print(summary(result))

}
