% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nmfkc.ard.R
\name{print.nmfkc.ard}
\alias{print.nmfkc.ard}
\title{Print method for nmfkc.ard objects}
\usage{
\method{print}{nmfkc.ard}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"nmfkc.ard"}.}

\item{...}{Unused.}
}
\value{
\code{x}, invisibly.
}
\description{
Print method for nmfkc.ard objects
}
