% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nmfkc.signed.R
\name{print.summary.nmfkc.signed}
\alias{print.summary.nmfkc.signed}
\title{Print method for summary.nmfkc.signed}
\usage{
\method{print}{summary.nmfkc.signed}(x, digits = max(3L, getOption("digits") - 3L), ...)
}
\arguments{
\item{x}{Object of class \code{"summary.nmfkc.signed"}.}

\item{digits}{Number of significant digits.}

\item{...}{Unused.}
}
\value{
Invisible \code{x}.
}
\description{
Print method for summary.nmfkc.signed
}
\section{Lifecycle}{

This function is \strong{experimental}. The interface may change in
future versions.
}

\references{
Ding, C. H. Q., Li, T., & Jordan, M. I. (2010). Convex and
semi-nonnegative matrix factorizations. \emph{IEEE Transactions on
Pattern Analysis and Machine Intelligence}, 32(1), 45--55.
}
