% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/s3methods.R
\name{print.nmf.inference}
\alias{print.nmf.inference}
\title{Print method for NMF inference objects}
\usage{
\method{print}{nmf.inference}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"nmf.inference"}.}

\item{...}{Additional arguments passed to the corresponding
\code{print.summary.*} method.}
}
\value{
Called for its side effect (printing). Returns \code{x} invisibly.
}
\description{
Prints a summary of any NMF inference result object
(\code{"nmfkc.inference"} or \code{"nmfae.inference"}).
}
\seealso{
\code{\link{nmfkc.inference}}, \code{\link{nmfae.inference}}
}
