% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nmfkc.net.R
\name{print.summary.nmfkc.net.signed}
\alias{print.summary.nmfkc.net.signed}
\title{Print method for summary.nmfkc.net.signed objects}
\usage{
\method{print}{summary.nmfkc.net.signed}(x, digits = max(3L, getOption("digits") - 3L), ...)
}
\arguments{
\item{x}{An object of class \code{"summary.nmfkc.net.signed"}.}

\item{digits}{Minimum number of significant digits.}

\item{...}{Unused.}
}
\value{
Invisible \code{x}.
}
\description{
Print method for summary.nmfkc.net.signed objects
}
\seealso{
\code{\link{summary.nmfkc.net.signed}}
}
