% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nmfkc.R
\name{print.nmf.rank}
\alias{print.nmf.rank}
\title{Print method for rank-selection (nmf.rank) objects}
\usage{
\method{print}{nmf.rank}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"nmf.rank"}.}

\item{...}{Passed to the criteria table's \code{print}.}
}
\value{
\code{x}, invisibly.
}
\description{
Print method for rank-selection (nmf.rank) objects
}
