% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nmfkc.net.R
\name{summary.nmfkc.net.signed}
\alias{summary.nmfkc.net.signed}
\title{Summary method for nmfkc.net.signed objects}
\usage{
\method{summary}{nmfkc.net.signed}(object, ...)
}
\arguments{
\item{object}{An \code{nmfkc.net.signed} object.}

\item{...}{Unused.}
}
\value{
An object of class \code{"summary.nmfkc.net.signed"}.
}
\description{
Summary method for nmfkc.net.signed objects
}
\seealso{
\code{\link{nmfkc.net}}
}
