% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nmfkc.ar.R
\name{nmfkc.ar.stationarity}
\alias{nmfkc.ar.stationarity}
\title{Check stationarity of an NMF-VAR model}
\usage{
nmfkc.ar.stationarity(x)
}
\arguments{
\item{x}{The return value of \code{nmfkc} for a VAR model.}
}
\value{
A list with components:
\item{spectral.radius}{Numeric. The spectral radius of the companion matrix. A value less than 1 indicates stationarity.}
\item{stationary}{Logical. \code{TRUE} if the spectral radius is less than 1 (i.e., the system is stationary), \code{FALSE} otherwise.}
}
\description{
\code{nmfkc.ar.stationarity} assesses the dynamic stability of a VAR model
by computing the spectral radius of its companion matrix.
It returns both the spectral radius and a logical indicator of stationarity.
}
\examples{
# Check stationarity of fitted AR model
d <- AirPassengers
ar_data <- nmfkc.ar(d, degree = 2)
result <- nmfkc(ar_data$Y, ar_data$A, rank = 1)
nmfkc.ar.stationarity(result)

}
\seealso{
\code{\link{nmfkc}}, \code{\link{nmfkc.ar}}
}
